#!/usr/bin/env python3


from libervia.server.constants import Const as C
from twisted.words.protocols.jabber import jid
from sat.core.log import getLogger

log = getLogger(__name__)
"""ticket handling pages"""

name = "tickets_disco"
access = C.PAGES_ACCESS_PUBLIC
template = "ticket/discover.html"


def prepare_render(self, request):
    tickets_trackers_config = self.host.options["tickets_trackers_json"]
    if tickets_trackers_config:
        trackers = request.template_data["tickets_trackers"] = []
        try:
            for tracker_data in tickets_trackers_config:
                service = tracker_data["service"]
                node = tracker_data["node"]
                name = tracker_data["name"]
                url = self.getPageByName("tickets").getURL(service, node)
                trackers.append({"name": name, "url": url})
        except KeyError as e:
            log.warning("Missing field in tickets_trackers_json: {msg}".format(msg=e))
        except Exception as e:
            log.warning("Can't decode tickets trackers: {msg}".format(msg=e))


def on_data_post(self, request):
    jid_str = self.getPostedData(request, "jid")
    try:
        jid_ = jid.JID(jid_str)
    except RuntimeError:
        self.pageError(request, C.HTTP_BAD_REQUEST)
    # for now we just use default node
    url = self.getPageByName("tickets").getURL(jid_.full(), "@")
    self.HTTPRedirect(request, url)
